summaryrefslogtreecommitdiff
path: root/src/mongo/db/geo/geometry_container.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/geo/geometry_container.h')
-rw-r--r--src/mongo/db/geo/geometry_container.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/mongo/db/geo/geometry_container.h b/src/mongo/db/geo/geometry_container.h
index 7bd054778ff..501b17ce687 100644
--- a/src/mongo/db/geo/geometry_container.h
+++ b/src/mongo/db/geo/geometry_container.h
@@ -46,9 +46,14 @@ namespace mongo {
GeometryContainer();
/**
* Loads an empty GeometryContainer from BSON
*/
- bool parseFrom(const BSONObj &obj);
+ Status parseFromQuery(const BSONElement& elem);
+
+ /**
+ * Loads an empty GeometryContainer from stored geometry.
+ */
+ Status parseFromStorage(const BSONElement& elem);
/**
* Is the geometry any of {Point, Line, Polygon}?
@@ -117,6 +122,8 @@ namespace mongo {
class R2BoxRegion;
+ Status parseFromGeoJSON(const BSONObj& obj);
+
// Does 'this' intersect with the provided type?
bool intersects(const S2Cell& otherPoint) const;
bool intersects(const S2Polyline& otherLine) const;
@@ -46,9 +46,14 @@ namespace mongo {
GeometryContainer();
/**
- * Loads an empty GeometryContainer from BSON
+ * Loads an empty GeometryContainer from query.
*/